==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/ad/DouJinCpcSolutionResult.java <==
package eleme.openapi.sdk.api.entity.ad;


import java.util.List;

public class DouJinCpcSolutionResult{

    /**
     * 计划id
     */
    private Long id;
    public Long getId() {
        return id;
    }
    public void setId(Long id) {
        this.id = id;
    }
    
    /**
     * 投放计划
     */
    private String title;
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    
    /**
     * 每日预算
     */
    private String budget;
    public String getBudget() {
        return budget;
    }
    public void setBudget(String budget) {
        this.budget = budget;
    }
    
    /**
     * 出价方式
     */
    private Integer bidModel;
    public Integer getBidModel() {
        return bidModel;
    }
    public void setBidModel(Integer bidModel) {
        this.bidModel = bidModel;
    }
    
    /**
     * 预算风格
     */
    private Integer budgetStyle;
    public Integer getBudgetStyle() {
        return budgetStyle;
    }
    public void setBudgetStyle(Integer budgetStyle) {
        this.budgetStyle = budgetStyle;
    }
    
    /**
     * 计划状态
     */
    private String state;
    public String getState() {
        return state;
    }
    public void setState(String state) {
        this.state = state;
    }
    
    /**
     * 是否启动自定义投放时段
     */
    private Boolean isAutoLaunch;
    public Boolean getIsAutoLaunch() {
        return isAutoLaunch;
    }
    public void setIsAutoLaunch(Boolean isAutoLaunch) {
        this.isAutoLaunch = isAutoLaunch;
    }
    
    /**
     * 工作日投放时段
     */
    private List<String> launchHoursHalfList;
    public List<String> getLaunchHoursHalfList() {
        return launchHoursHalfList;
    }
    public void setLaunchHoursHalfList(List<String> launchHoursHalfList) {
        this.launchHoursHalfList = launchHoursHalfList;
    }
    
    /**
     * 单元明细
     */
    private List<AdGroupResult> adgroupList;
    public List<AdGroupResult> getAdgroupList() {
        return adgroupList;
    }
    public void setAdgroupList(List<AdGroupResult> adgroupList) {
        this.adgroupList = adgroupList;
    }
    
    /**
     * 定向出价明细
     */
    private List<TargetResult> targetList;
    public List<TargetResult> getTargetList() {
        return targetList;
    }
    public void setTargetList(List<TargetResult> targetList) {
        this.targetList = targetList;
    }
    
}

==> eleme-openapi-sdk-1.30.85-sources.jar: eleme/openapi/sdk/api/entity/ad/DouJinCpcSolutionResult.java <==
package eleme.openapi.sdk.api.entity.ad;

import eleme.openapi.sdk.api.enumeration.ad.*;
import eleme.openapi.sdk.api.entity.ad.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class DouJinCpcSolutionResult{

    /**
     * 计划id
     */
    private Long id;
    public Long getId() {
        return id;
    }
    public void setId(Long id) {
        this.id = id;
    }
    
    /**
     * 投放计划
     */
    private String title;
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    
    /**
     * 每日预算
     */
    private String budget;
    public String getBudget() {
        return budget;
    }
    public void setBudget(String budget) {
        this.budget = budget;
    }
    
    /**
     * 出价方式
     */
    private Integer bidModel;
    public Integer getBidModel() {
        return bidModel;
    }
    public void setBidModel(Integer bidModel) {
        this.bidModel = bidModel;
    }
    
    /**
     * 出价类型
     */
    private String bidStyle;
    public String getBidStyle() {
        return bidStyle;
    }
    public void setBidStyle(String bidStyle) {
        this.bidStyle = bidStyle;
    }
    
    /**
     * 预算风格
     */
    private Integer budgetStyle;
    public Integer getBudgetStyle() {
        return budgetStyle;
    }
    public void setBudgetStyle(Integer budgetStyle) {
        this.budgetStyle = budgetStyle;
    }
    
    /**
     * 计划状态
     */
    private String state;
    public String getState() {
        return state;
    }
    public void setState(String state) {
        this.state = state;
    }
    
    /**
     * 是否启动自定义投放时段
     */
    private Boolean isAutoLaunch;
    public Boolean getIsAutoLaunch() {
        return isAutoLaunch;
    }
    public void setIsAutoLaunch(Boolean isAutoLaunch) {
        this.isAutoLaunch = isAutoLaunch;
    }
    
    /**
     * 工作日投放时段
     */
    private List<String> launchHoursHalfList;
    public List<String> getLaunchHoursHalfList() {
        return launchHoursHalfList;
    }
    public void setLaunchHoursHalfList(List<String> launchHoursHalfList) {
        this.launchHoursHalfList = launchHoursHalfList;
    }
    
    /**
     * 单元明细
     */
    private List<AdGroupResult> adgroupList;
    public List<AdGroupResult> getAdgroupList() {
        return adgroupList;
    }
    public void setAdgroupList(List<AdGroupResult> adgroupList) {
        this.adgroupList = adgroupList;
    }
    
    /**
     * 定向出价明细
     */
    private List<TargetResult> targetList;
    public List<TargetResult> getTargetList() {
        return targetList;
    }
    public void setTargetList(List<TargetResult> targetList) {
        this.targetList = targetList;
    }
    
}
